<?php

namespace Schaffen\Core\Person\Models;

use Illuminate\Database\Eloquent\Model;
use Schaffen\Core\Employee\Models\Employee;
use Schaffen\Core\User\Models\User;
use Schaffen\Financial\BillingRoute\Models\ClientRoute;
use Schaffen\Financial\BillingRoute\Models\Route;
use Schaffen\Financial\BillingRoute\Models\SalesmanRoute;
use Schaffen\WarehouseInventory\WarehouseInventory\Models\WarehouseInventory;

class Person extends Model
{
    protected $connection = 'dynamicdb';
    public $hidden = ["pes_imagem"];
    protected $table = "cadastro.pessoa";
    protected $primaryKey = "pes_codigo";
    const CREATED_AT = 'pes_date_insert';
    const UPDATED_AT = 'pes_date_update';
    protected $fillable = [
        "pes_codigo",
        "pes_nome",
        "pes_identificador",
        "pes_tipo",
        "pes_razao_social",
        "pes_user_insert",
        "pes_user_update",
        "pes_codigo_externo",
        "pes_inscricao_estadual",
        "pes_nome_reduzido",
        "pes_fk_fil_codigo",
        "pes_imagem",
        "pes_observacao",
        "pes_limite_credito",
        "pes_status",
        "pes_cad_pro",
        "pes_inscricao_municipal",
        "pes_dias_bloqueio_os",
        'pes_cad_incompleto'
    ];

    // protected $with = [
    //     'address', 
    //     'contact'
    // ];   

    public function employee()
    {
        return $this->hasOne(Employee::class, 'fun_fk_pes_codigo');
    }

    public function users()
    {
        return $this->hasMany(User::class, 'usu_fk_pes_codigo');
    }

    public function address()
    {
        return $this->hasMany(Address::class, 'pee_fk_pes_codigo');
    }

    public function route()
    {
        return $this->hasManyThrough(
            Route::class,
            SalesmanRoute::class,
            'rov_fk_pes_codigo',
            'rot_codigo',
            'pes_codigo',
            'rov_fk_rot_codigo'
        )->with('clients');
    }

    public function route_client()
    {
        return $this->hasManyThrough(
            Route::class,
            ClientRoute::class,
            'roc_fk_pes_codigo',
            'rot_codigo',
            'pes_codigo',
            'roc_fk_rot_codigo',
        );
    }

    public function rota_cliente()
    {
        return $this->hasOne(ClientRoute::class, 'roc_fk_pes_codigo');
    }

    public function contact()
    {
        return $this->hasMany(Contact::class, 'peco_fk_pes_codigo');
    }

    public function default_address()
    {
        return $this->hasOne(Address::class, 'pee_fk_pes_codigo')->where('pee_padrao', 1)->withDefault(
            [
                'pee_logradouro' => 'SEM ENDEREÇO PADRÃO',
                'pee_numero' => '',
                'pee_bairro' => '',
                'pee_cidade' => '',
                "pee_latitude" => null,
                "pee_longitude" => null
            ]
        );
    }


    public function rota_que_pertence_cliente()
    {
        return $this->hasOne(ClientRoute::class, 'roc_fk_pes_codigo')->with('route');
    }

    public function contact_default()
    {
        return $this->hasOne(Contact::class, 'peco_fk_pes_codigo')->where('peco_padrao', '=', 1);
    }

    public function address_default()
    {
        return $this->hasOne(Address::class, 'pee_fk_pes_codigo')->where('pee_padrao', '=', 1);
    }

    public function branch(){
        return $this->hasOne(PersonBranch::class, 'pef_fk_pes_codigo');
    }
    public function person_modality(){
        return $this->hasOne(PersonModality::class, 'pem_fk_pes_codigo');
    }


    public function warehouse_inventory(){
        return $this->hasOne(WarehouseInventory::class, 'loe_fk_pes_codigo');
    }
}
